"""
setup.py

Setup configuration for the package.

:author:        Stephen Stauts
:created:       20/08/2020   (DD/MM/YYYY)
:copyright:     © 2020 Stephen Stauts. All Rights Reserved.
"""

from pathlib import Path
import os
import setuptools

PACKAGE_NAME = 'yinter'
PIP_NAME = 'yinter'


def get_version():
    """
    Access package version without importing.

    :reference: https://github.com/paramiko/paramiko/blob/master/setup.py#L38
    """
    _locals = {}
    with open(Path(os.getcwd(), 'src', PACKAGE_NAME, 'version.py')) as f:
        exec(f.read(), None, _locals)
    return _locals['__version__']


def get_long_description():
    """Read the contents of the README file."""
    p_readme = Path(os.getcwd(), 'README.md')
    with open(str(p_readme.absolute()), encoding='utf-8') as f:
        long_description = f.read()
    return long_description


setuptools.setup(
    name=PIP_NAME,
    version=get_version(),
    description='Value interpolator for YAML files.',
    long_description=get_long_description(),
    long_description_content_type='text/markdown',
    url='https://gitlab.com/kyberdin/yinter',
    author='Stephen Stauts',
    author_email='kyberdin.git@gmail.com',
    license='MIT',
    keywords='utilities util interpolation yaml',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: MIT License',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    python_requires='>=3.8',
    package_dir = {'': 'src'},
    packages=[
        PACKAGE_NAME
    ],
    install_requires=[
        'futils>=0.3.0',
        'pyyaml>=5.3.1'
    ],
)
